==> apache-devlake-0.17.0-incubating-src.tar.gz: apache-devlake-0.17.0-incubating-src/config-ui/src/pages/blueprint/detail/styled.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

import styled from 'styled-components';

export const Wrapper = styled.div`
  padding-bottom: 24px;
`;

export const ConfigurationPanel = styled.div`
  .top {
    display: flex;
    align-items: flex-start;
    justify-content: space-between;

    ul {
      display: flex;
      align-items: flex-start;

      li + li {
        margin-left: 48px;
      }
    }

    .detail {
      .bp4-icon {
        margin-left: 4px;
        cursor: pointer;
      }
    }
  }

  .bottom {
    margin-top: 24px;

    h3 {
      display: flex;
      align-items: center;
      justify-content: space-between;
    }

    .btns {
      margin-top: 16px;
      text-align: right;
    }
  }
`;

export const ConnectionColumn = styled.div`
  display: flex;
  align-items: center;

  img {
    margin-right: 4px;
    width: 20px;
  }
`;

export const ActionColumn = styled.div`
  display: inline-flex;
  flex-direction: column;
  align-items: flex-start;

  .item + .item {
    margin-top: 8px;
  }

  .item {
    cursor: pointer;

    .bp4-icon {
      margin-right: 4px;
    }
  }
`;

export const StatusPanel = styled.div`
  & > .info {
    display: flex;
    justify-content: flex-end;
    align-items: center;

    & > span {
      margin-left: 16px;
    }

    .bp4-switch {
      margin-bottom: 0;
    }
  }

  .block + .block {
    margin-top: 32px;
  }
`;

export const JenkinsTips = styled.div`
  position: fixed;
  right: 0;
  bottom: 0;
  left: 200px;
  background-color: #3c5088;
  display: flex;
  align-items: center;
  justify-content: center;
  height: 36px;

  p {
    margin: 0;
    color: #fff;
  }
`;

==> apache-devlake-0.19.0-incubating-src.tar.gz: apache-devlake-0.19.0-incubating-src/config-ui/src/pages/blueprint/detail/styled.ts <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

import styled from 'styled-components';

export const Wrapper = styled.div`
  padding-bottom: 24px;
`;

export const DialogBody = styled.div`
  display: flex;
  align-items: center;

  .bp4-icon {
    margin-right: 8px;
    color: #f4be55;
  }
`;

export const ConfigurationPanel = styled.div`
  .block + .block {
    margin-top: 36px;
  }

  h3 {
    margin-bottom: 16px;
  }

  .btns {
    margin-top: 16px;
    text-align: right;
  }
`;

export const ConnectionList = styled.ul`
  display: flex;
  align-items: center;
`;

export const ConnectionItem = styled.li`
  margin-right: 24px;
  padding: 12px 16px;
  width: 280px;
  background: #ffffff;
  box-shadow: 0px 2.4px 4.8px -0.8px rgba(0, 0, 0, 0.1), 0px 1.6px 8px rgba(0, 0, 0, 0.07);
  border-radius: 4px;

  &:last-child {
    margin-right: 0;
  }

  .title {
    display: flex;
    align-items: center;

    img {
      width: 24px;
      height: 24px;
    }

    span {
      margin-left: 8px;
    }
  }

  .count {
    margin: 24px 0;
  }
`;

export const StatusPanel = styled.div`
  h3 {
    margin-bottom: 16px;
  }

  .block + .block {
    margin-top: 32px;
  }
`;

export const ProjectACtion = styled.div`
  display: flex;
  justify-content: flex-end;
  align-items: center;

  & > * {
    margin-left: 16px;
  }
`;

export const BlueprintAction = styled.div`
  display: flex;
  justify-content: center;
  align-items: center;

  & > .bp4-switch {
    margin: 0 8px;
  }
`;
